//
//  ImageExtensionGeneratorTests.swift
//  
//
//  Created by Thibaut Schmitt on 05/09/2022.
//

import Foundation
import XCTest
import ToolCore

@testable import ResgenSwift

final class ImageExtensionGeneratorTests: XCTestCase {
    
    func testGeneratedExtensionContent() {
        // Given
        let images = [
            ParsedImage(name: "image_one", tags: "id", width: 10, height: 10),
            ParsedImage(name: "image_two", tags: "id", width: 180, height: 90),
        ]
        
        // When
        let extensionContent = ImageExtensionGenerator.getExtensionContent(images: images,
                                                                           staticVar: false,
                                                                           extensionName: "GenImages",
                                                                           inputFilename: "myInputFilename")
        
        // Expect
        let expect = """
        // Generated by ResgenSwift.Images \(ResgenSwiftVersion)
        // Images from myInputFilename
        
        import UIKit
        
        extension GenImages {
        
            var image_one: UIImage {
                UIImage(named: "image_one")!
            }
        
            var image_two: UIImage {
                UIImage(named: "image_two")!
            }
        }
        """
        
        XCTAssertEqual(extensionContent.adaptForXCTest(), expect.adaptForXCTest())
    }
    
    func testGeneratedExtensionContentForStaticVar() {
        // Given
        let images = [
            ParsedImage(name: "image_one", tags: "id", width: 10, height: 10),
            ParsedImage(name: "image_two", tags: "id", width: 180, height: 90),
        ]
        
        // When
        let extensionContent = ImageExtensionGenerator.getExtensionContent(images: images,
                                                                           staticVar: true,
                                                                           extensionName: "GenImages",
                                                                           inputFilename: "myInputFilename")
        
        // Expect
        let expect = """
        // Generated by ResgenSwift.Images \(ResgenSwiftVersion)
        // Images from myInputFilename
        
        import UIKit
        
        extension GenImages {
        
            static var image_one: UIImage {
                UIImage(named: "image_one")!
            }
        
            static var image_two: UIImage {
                UIImage(named: "image_two")!
            }
        }
        """
        
        XCTAssertEqual(extensionContent.adaptForXCTest(), expect.adaptForXCTest())
    }
}
